@@ -210,7 +210,7 @@ fi
 
 # Add on extra jar files to CLASSPATH
 # shellcheck disable=SC2236
-if [[ ! -z "$CLASSPATH" ]]; then
+if [ ! -z "$CLASSPATH" ]; then
   CLASSPATH="$CLASSPATH":
 fi
 CLASSPATH="$CLASSPATH"
@@ -229,18 +229,7 @@ if ${cygwin}; then
   CLASSPATH=`cygpath --path --windows "$CLASSPATH"`
 fi
 
-# get jdk version, return version as an Integer.
-JDK_VERSION=$("$_RUNJAVA" -version 2>&1 | grep -i 'version' | head -n 1 | cut -d '"' -f 2)
-MAJOR_VER=$(echo "$JDK_VERSION" 2>&1 | cut -d '.' -f 1)
-[[ $MAJOR_VER -eq 1 ]] && MAJOR_VER=$(echo "$JDK_VERSION" 2>&1 | cut -d '.' -f 2)
-MIN_VERSION=8
-
-if [[ $MAJOR_VER -lt $MIN_VERSION ]]; then
-  echo "JDK Version: \"${JDK_VERSION}\", the version cannot be lower than 1.8"
-  exit 1
-fi
-
-if [[ -z "$USE_NOHUP" ]]; then
+if [ -z "$USE_NOHUP" ]; then
   if $hpux; then
     USE_NOHUP="true"
   else
@@ -248,45 +237,30 @@ if [[ -z "$USE_NOHUP" ]]; then
   fi
 fi
 unset NOHUP
-if [[ "$USE_NOHUP" = "true" ]]; then
+if [ "$USE_NOHUP" = "true" ]; then
   NOHUP="nohup"
 fi
 
-CONFIG="${APP_CONF}/application.yml"
-# shellcheck disable=SC2006
-if [[ -f "$CONFIG" ]] ; then
-  echo_y """[WARN] in the \"conf\" directory, found the \"application.yml\" file. The \"application.yml\" file is deprecated.
-     For compatibility, this application.yml will be used preferentially. The latest configuration file is \"config.yaml\". It is recommended to use \"config.yaml\".
-     Note: \"application.yml\" will be completely deprecated in version 2.2.0. """
-else
-  CONFIG="${APP_CONF}/config.yaml"
-  if [[ ! -f "$CONFIG" ]] ; then
-    echo_r "can not found config.yaml in \"conf\" directory, please check."
-    exit 1;
-  fi
-fi
 
-BASH_UTIL="org.apache.streampark.console.base.util.BashJavaUtils"
+PARAM_CLI="org.apache.streampark.flink.core.conf.ParameterCli"
+
 APP_MAIN="org.apache.streampark.console.StreamParkConsoleBootstrap"
-JVM_OPTS_FILE=${APP_HOME}/bin/jvm_opts.sh
 
-JVM_ARGS=""
-if [[ -f $JVM_OPTS_FILE ]]; then
-  while read line
-  do
-      if [[ "$line" == -* ]]; then
-        JVM_ARGS="${JVM_ARGS} $line"
-      fi
-  done < $JVM_OPTS_FILE
-fi
+DEFAULT_OPTS="""
+  -ea
+  -server
+  -Xms1024m
+  -Xmx1024m
+  -Xmn256m
+  -XX:NewSize=100m
+  -XX:+UseConcMarkSweepGC
+  -XX:CMSInitiatingOccupancyFraction=70
+  -XX:ThreadStackSize=512
+  -Xloggc:${APP_HOME}/logs/gc.log
+  """
 
-JAVA_OPTS=${JAVA_OPTS:-"${JVM_ARGS}"}
-JAVA_OPTS="$JAVA_OPTS -XX:HeapDumpPath=${APP_HOME}/logs/dump.hprof"
-JAVA_OPTS="$JAVA_OPTS -Xloggc:${APP_HOME}/logs/gc.log"
-[[ $MAJOR_VER -gt $MIN_VERSION ]] && JAVA_OPTS="$JAVA_OPTS --add-opens java.base/jdk.internal.loader=ALL-UNNAMED --add-opens jdk.zipfs/jdk.nio.zipfs=ALL-UNNAMED"
-[[ $MAJOR_VER -ge 17 ]] && JAVA_OPTS="$JAVA_OPTS -Djava.security.manager=allow"
+DEBUG_OPTS=""
 
-SERVER_PORT=$($_RUNJAVA -cp "$APP_LIB/*" $BASH_UTIL --get_yaml "server.port" "$CONFIG")
 # ----- Execute The Requested Command -----------------------------------------
 
 print_logo() {
@@ -297,25 +271,39 @@ print_logo() {
   printf '      %s  ___/ / /_/ /  /  __/ /_/ / / / / / / /_/ / /_/ / /  / ,<        %s\n'          $PRIMARY $RESET
   printf '      %s /____/\__/_/   \___/\__,_/_/ /_/ /_/ ____/\__,_/_/  /_/|_|       %s\n'          $PRIMARY $RESET
   printf '      %s                                   /_/                            %s\n\n'        $PRIMARY $RESET
-  printf '      %s   Version:  2.1.5 %s\n'                                                         $BLUE   $RESET
-  printf '      %s   WebSite:  https://streampark.apache.org%s\n'                                  $BLUE   $RESET
+  printf '      %s   Version:  2.1.0 %s\n'                                                $BLUE   $RESET
+  printf '      %s   WebSite:  https://streampark.apache.org%s\n'                                   $BLUE   $RESET
   printf '      %s   GitHub :  http://github.com/apache/streampark%s\n\n'                          $BLUE   $RESET
   printf '      %s   ──────── Apache StreamPark, Make stream processing easier ô~ô!%s\n\n'         $PRIMARY  $RESET
-  if [[ "$1"x == "start"x ]]; then
-    printf '      %s                   http://localhost:%s %s\n\n'                                 $PRIMARY $SERVER_PORT   $RESET
-  fi
+}
+
+parse_yaml() {
+   local prefix=$2
+   local s='[[:space:]]*' w='[a-zA-Z0-9_]*' fs=$(echo @|tr @ '\034')
+   sed -ne "s|^\($s\):|\1|" \
+        -e "s|^\($s\)\($w\)$s:$s[\"']\(.*\)[\"']$s\$|\1$fs\2$fs\3|p" \
+        -e "s|^\($s\)\($w\)$s:$s\(.*\)$s\$|\1$fs\2$fs\3|p"  $1 |
+   awk -F$fs '{
+      indent = length($1)/2;
+      vname[indent] = $2;
+      for (i in vname) {if (i > indent) {delete vname[i]}}
+      if (length($3) > 0) {
+         vn=""; for (i=0; i<indent; i++) {vn=(vn)(vname[i])("_")}
+         printf("%s%s%s=\"%s\"\n", "'$prefix'",vn, $2, $3);
+      }
+   }'
 }
 
 # shellcheck disable=SC2120
 get_pid() {
-  if [[ -f "$APP_PID" ]]; then
-    if [[ -s "$APP_PID" ]]; then
+  if [ -f "$APP_PID" ]; then
+    if [ -s "$APP_PID" ]; then
       # shellcheck disable=SC2155
       # shellcheck disable=SC2006
       local PID=`cat "$APP_PID"`
       kill -0 $PID >/dev/null 2>&1
       # shellcheck disable=SC2181
-      if [[ $? -eq 0 ]]; then
+      if [ $? -eq 0 ]; then
         echo $PID
         exit 0
       fi
@@ -325,25 +313,31 @@ get_pid() {
   fi
 
   # shellcheck disable=SC2006
-  if [[ "${SERVER_PORT}"x == ""x ]]; then
-    echo_r "server.port is required, please check $CONFIG"
+  local PROPER="${APP_CONF}/application.yml"
+  if [[ ! -f "$PROPER" ]] ; then
+    echo_r "ERROR: config file application.yml invalid or not found! ";
     exit 1;
+  fi
+
+  # shellcheck disable=SC2046
+  eval $(parse_yaml "${PROPER}" "conf_")
+  # shellcheck disable=SC2154
+  # shellcheck disable=SC2155
+  # shellcheck disable=SC2116
+  local serverPort=$(echo "$conf_server_port")
+  # shellcheck disable=SC2006
+  # shellcheck disable=SC2155
+  local used=`lsof -i:"$serverPort" | wc -l`
+  if [ "$used" -gt 0 ]; then
+    # shellcheck disable=SC2006
+    local PID=`jps -l | grep "$APP_MAIN" | awk '{print $1}'`
+    if [ ! -z $PID ]; then
+      echo $PID
+    else
+      echo 0
+    fi
   else
-     # shellcheck disable=SC2006
-      # shellcheck disable=SC2155
-      local used=`$_RUNJAVA -cp "$APP_LIB/*" $BASH_UTIL --check_port "$SERVER_PORT"`
-      if [[ "${used}"x == "used"x ]]; then
-        # shellcheck disable=SC2006
-        local PID=`jps -l | grep "$APP_MAIN" | awk '{print $1}'`
-        # shellcheck disable=SC2236
-        if [[ ! -z $PID ]]; then
-          echo "$PID"
-        else
-          echo 0
-        fi
-      else
-        echo 0
-      fi
+    echo 0
   fi
 }
 
@@ -352,7 +346,7 @@ start() {
   # shellcheck disable=SC2006
   local PID=$(get_pid)
 
-  if [[ $PID -gt 0 ]]; then
+  if [ $PID -gt 0 ]; then
     # shellcheck disable=SC2006
     echo_r "StreamPark is already running pid: $PID , start aborted!"
     exit 1
@@ -370,21 +364,32 @@ start() {
     echo_w "Using APP_PID:   $APP_PID"
   fi
 
-   # shellcheck disable=SC2006
-   local workspace=`$_RUNJAVA -cp "$APP_LIB/*" $BASH_UTIL --get_yaml "streampark.workspace.local" "$CONFIG"`
-   if [[ ! -d $workspace ]]; then
-     echo_r "ERROR: streampark.workspace.local: \"$workspace\" is an invalid path, please reconfigure in $CONFIG"
-     echo_r "NOTE: \"streampark.workspace.local\" should not be set under APP_HOME($APP_HOME) directory. Set it to a secure directory outside of APP_HOME."
-     exit 1;
-   fi
+  local PROPER="${APP_CONF}/application.yml"
+  if [[ ! -f "$PROPER" ]] ; then
+    echo_r "ERROR: config file application.yml invalid or not found! ";
+    exit 1;
+  else
+    echo_g "Usage: config file: $PROPER ";
+  fi
 
+  # shellcheck disable=SC2046
+  eval $(parse_yaml "${PROPER}" "conf_")
+  # shellcheck disable=SC2001
+  # shellcheck disable=SC2154
+  # shellcheck disable=SC2155
+  local workspace=$(echo "$conf_streampark_workspace_local" | sed 's/#.*$//g')
+  if [[ ! -d $workspace ]]; then
+    echo_r "ERROR: streampark.workspace.local: \"$workspace\" is invalid path, Please reconfigure in application.yml"
+    echo_r "NOTE: \"streampark.workspace.local\" Do not set under APP_HOME($APP_HOME). Set it to a secure directory outside of APP_HOME.  "
+    exit 1;
+  fi
   if [[ ! -w $workspace ]] || [[ ! -r $workspace ]]; then
       echo_r "ERROR: streampark.workspace.local: \"$workspace\" Permission denied! "
       exit 1;
   fi
 
-  if [[ "${HADOOP_HOME}"x == ""x ]]; then
-    echo_y "WARN: HADOOP_HOME is undefined on your system env."
+  if [ "${HADOOP_HOME}"x == ""x ]; then
+    echo_y "WARN: HADOOP_HOME is undefined on your system env,please check it."
   else
     echo_w "Using HADOOP_HOME:   ${HADOOP_HOME}"
   fi
@@ -411,14 +416,23 @@ start() {
     APP_CLASSPATH+=":${HADOOP_HOME}/etc/hadoop"
   fi
 
-  echo_g "JAVA_OPTS:  ${JAVA_OPTS}"
+  # shellcheck disable=SC2034
+  # shellcheck disable=SC2006
+  local vmOption=`$_RUNJAVA -cp "$APP_CLASSPATH" $PARAM_CLI --vmopt`
+
+  local JAVA_OPTS="""
+  $vmOption
+  $DEFAULT_OPTS
+  $DEBUG_OPTS
+  """
 
   eval $NOHUP $_RUNJAVA $JAVA_OPTS \
     -classpath "$APP_CLASSPATH" \
     -Dapp.home="${APP_HOME}" \
-    -Djava.io.tmpdir="$APP_TMPDIR" \
     -Dlogging.config="${APP_CONF}/logback-spring.xml" \
-    $APP_MAIN "$@" >> "$APP_OUT" 2>&1 "&"
+    -Dspring.config.location="${PROPER}" \
+    -Djava.io.tmpdir="$APP_TMPDIR" \
+    $APP_MAIN >> "$APP_OUT" 2>&1 "&"
 
     local PID=$!
     local IS_NUMBER="^[0-9]+$"
@@ -448,7 +462,15 @@ start_docker() {
     echo_w "Using APP_PID:   $APP_PID"
   fi
 
-  if [[ "${HADOOP_HOME}"x == ""x ]]; then
+  local PROPER="${APP_CONF}/application.yml"
+  if [[ ! -f "$PROPER" ]] ; then
+    echo_r "ERROR: config file application.yml invalid or not found! ";
+    exit 1;
+  else
+    echo_g "Usage: config file: $PROPER ";
+  fi
+
+  if [ "${HADOOP_HOME}"x == ""x ]; then
     echo_y "WARN: HADOOP_HOME is undefined on your system env,please check it."
   else
     echo_w "Using HADOOP_HOME:   ${HADOOP_HOME}"
@@ -475,19 +497,37 @@ start_docker() {
     APP_CLASSPATH+=":${HADOOP_HOME}/etc/hadoop"
   fi
 
-  JAVA_OPTS="$JAVA_OPTS -XX:-UseContainerSupport"
+  # shellcheck disable=SC2034
+  # shellcheck disable=SC2006
+  local vmOption=`$_RUNJAVA -cp "$APP_CLASSPATH" $PARAM_CLI --vmopt`
 
-  echo_g "JAVA_OPTS:  ${JAVA_OPTS}"
+  local JAVA_OPTS="""
+    $vmOption
+    $DEFAULT_OPTS
+    $DEBUG_OPTS
+    """
 
   $_RUNJAVA $JAVA_OPTS \
     -classpath "$APP_CLASSPATH" \
     -Dapp.home="${APP_HOME}" \
-    -Djava.io.tmpdir="$APP_TMPDIR" \
     -Dlogging.config="${APP_CONF}/logback-spring.xml" \
+    -Dspring.config.location="${PROPER}" \
+    -Djava.io.tmpdir="$APP_TMPDIR" \
     $APP_MAIN
 
 }
 
+debug() {
+  if [ ! -n "$DEBUG_PORT" ]; then
+    echo_r "If start with debug mode,Please fill in the debug port like: bash streampark.sh debug 10002 "
+  else
+    DEBUG_OPTS="""
+    -Xdebug  -Xrunjdwp:transport=dt_socket,server=y,suspend=n,address=$DEBUG_PORT
+    """
+    start
+  fi
+}
+
 # shellcheck disable=SC2120
 stop() {
   # shellcheck disable=SC2155
@@ -506,17 +546,17 @@ stop() {
   # shellcheck disable=SC2006
   echo_g "StreamPark stopping with the PID: $PID"
 
-  kill -9 "$PID"
+  kill -9 $PID
 
   while [ $SLEEP -ge 0 ]; do
     # shellcheck disable=SC2046
     # shellcheck disable=SC2006
-    kill -0 "$PID" >/dev/null 2>&1
+    kill -0 $PID >/dev/null 2>&1
     # shellcheck disable=SC2181
-    if [[ $? -gt 0 ]]; then
+    if [ $? -gt 0 ]; then
       rm -f "$APP_PID" >/dev/null 2>&1
-      if [[ $? != 0 ]]; then
-        if [[ -w "$APP_PID" ]]; then
+      if [ $? != 0 ]; then
+        if [ -w "$APP_PID" ]; then
           cat /dev/null > "$APP_PID"
         else
           echo_r "The PID file could not be removed."
@@ -526,7 +566,7 @@ stop() {
       break
     fi
 
-    if [[ $SLEEP -gt 0 ]]; then
+    if [ $SLEEP -gt 0 ]; then
        sleep 1
     fi
     # shellcheck disable=SC2006
@@ -534,7 +574,7 @@ stop() {
     SLEEP=`expr $SLEEP - 1 `
   done
 
-  if [[ "$SLEEP" -lt 0 ]]; then
+  if [ "$SLEEP" -lt 0 ]; then
      echo_r "StreamPark has not been killed completely yet. The process might be waiting on some system call or might be UNINTERRUPTIBLE."
   fi
 }
@@ -543,7 +583,7 @@ status() {
   # shellcheck disable=SC2155
   # shellcheck disable=SC2006
   local PID=$(get_pid)
-  if [[ $PID -eq 0 ]]; then
+  if [ $PID -eq 0 ]; then
     echo_r "StreamPark is not running"
   else
     echo_g "StreamPark is running pid is: $PID"
@@ -558,37 +598,36 @@ restart() {
 }
 
 main() {
+  print_logo
   case "$1" in
+    "debug")
+        DEBUG_PORT=$2
+        debug
+        ;;
     "start")
-        shift
-        start "$@"
-        [[ $? -eq 0 ]] && print_logo "start"
+        start
         ;;
     "start_docker")
-        print_logo
         start_docker
         ;;
     "stop")
-        print_logo
         stop
         ;;
     "status")
-        print_logo
         status
         ;;
     "restart")
         restart
-        [[ $? -eq 0 ]] && print_logo "start"
         ;;
     *)
         echo_r "Unknown command: $1"
         echo_w "Usage: streampark.sh ( commands ... )"
         echo_w "commands:"
-        echo_w "  start \$conf              Start StreamPark with application config."
+        echo_w "  start \$conf               Start StreamPark with application config."
         echo_w "  stop                      Stop StreamPark, wait up to 3 seconds and then use kill -KILL if still running"
-        echo_w "  start_docker              start in docker or k8s mode"
         echo_w "  status                    StreamPark status"
-        echo_w "  restart \$conf            restart StreamPark with application config."
+        echo_w "  debug                     StreamPark start with debug mode,start debug mode, like: bash streampark.sh debug 10002"
+        echo_w "  restart \$conf             restart StreamPark with application config."
         exit 0
         ;;
   esac
